"""Common functions."""

import os
import re
from textwrap import wrap
from xml.sax.saxutils import escape

re_startspace = re.compile("^\s*")


def flatten_config(cp):
    """
    Flatten a ini-file at returns all the key/value as dict.

    :type cp: ConfigParser
    :rtype: dict
    """
    config = {}
    for section in cp.sections():
        for option in cp.options(section):
            config[option] = cp.get(section, option)
    return config


def prepare_text_for_xml(text):
    """Prepare a text for generating xml."""
    lines = []
    do_wrap = any(len(line) > 83 for line in text.splitlines())
    if do_wrap:
        paras = []
        for paragraph in text.splitlines():
            first = re_startspace.match(paragraph).group()
            others = ""
            if len(first):
                others = "%s    " % first
            paras.append(
                os.linesep.join(
                    wrap(
                        paragraph.lstrip(),
                        width=80,
                        initial_indent=first,
                        subsequent_indent=others
                    )
                )
            )
        new_text = os.linesep.join(paras)
    else:
        new_text = text
    new_text = new_text.splitlines()
    for line in new_text:
        lines.append(escape(line))
    return lines
